@@ -1,5 +1,5 @@
 `psxy` <-
-function(x, cmd="-JM -R -Scp -W2p -O -K", file=getOption("gmt.file"))
+function(x, cmd="-J -R -Scp -W2p -O -K", file=getOption("gmt.file"))
 {
   if(is.null(file)) stop("Please pass a valid 'file' argument, or run gmt(file=\"myfile\").")
   owd <- setwd(dirname(file)); on.exit(setwd(owd))
